//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/AxesItems.h
//! @brief     Defines various axis items
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DEVICE_AXESITEMS_H
#define BORNAGAIN_GUI_MODEL_DEVICE_AXESITEMS_H

#include "GUI/Model/BaseItem/SessionItem.h"
#include "GUI/Model/Descriptor/DoubleDescriptor.h" // no forward declaration < used in many children
#include <memory>

class IAxis;
class Streamer;

class BasicAxisItem : public QObject, public SessionItem {
    Q_OBJECT
private:
    static constexpr auto P_IS_VISIBLE{"Visibility"};
    static constexpr auto P_NBINS{"Nbins"};
    static constexpr auto P_MIN_DEG{"Min [deg]"};
    static constexpr auto P_MAX_DEG{"Max [deg]"};
    static constexpr auto P_TITLE{"Title"};
    static constexpr auto P_TITLE_IS_VISIBLE{"Title Visibility"};

public:
    static constexpr auto M_TYPE{"BasicAxis"};

    BasicAxisItem();
    ~BasicAxisItem() override;

    virtual void serialize(Streamer& s);

    int binCount() const;
    void setBinCount(size_t value);
    SessionItem* binsItem() const;

    double min() const;
    void setMin(double value);
    SessionItem* minItem() const;

    double max() const;
    void setMax(double value);
    SessionItem* maxItem() const;

    QString title() const;
    void setTitle(const QString& title);
    bool isTitleVisible() const;

    virtual std::unique_ptr<IAxis> createAxis(double scale) const;

    SessionItem* visibilityItem() const;
    bool isVisible() const;
    void setVisibilityValue(bool b);

signals:
    void axisRangeChanged();
    void axisTitleChanged();
    void axisVisibilityChanged();

protected:
    explicit BasicAxisItem(const QString& type);
};

class AmplitudeAxisItem : public BasicAxisItem {
    Q_OBJECT
private:
    static constexpr auto P_IS_LOGSCALE{"log10"};
    static constexpr auto P_LOCK_MIN_MAX{"Lock (min, max)"};

public:
    static constexpr auto M_TYPE{"AmplitudeAxis"};

    AmplitudeAxisItem();
    void serialize(Streamer& s) override;

    bool isLogScale() const;
    void setLogScale(bool value);
    SessionItem* logScaleItem() const;

    bool isLocked() const;
    void setLocked(bool locked);

signals:
    void logScaleChanged(bool isLog);
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_AXESITEMS_H
