//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Job/FitSuiteItem.cpp
//! @brief     Implements class FitSuiteItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Job/FitSuiteItem.h"
#include "GUI/Model/Job/FitParameterContainerItem.h"
#include "GUI/Model/Job/MinimizerItem.h"
#include "GUI/Model/Model/SessionModel.h"
#include "GUI/Util/Error.h"

FitSuiteItem::FitSuiteItem()
    : SessionItem(M_TYPE)
{
    addProperty(P_UPDATE_INTERVAL, 10);
    addProperty(P_ITERATION_COUNT, 0);
    addProperty(P_CHI2, 0.0);

    registerTag(T_FIT_PARAMETERS_CONTAINER, 1, 1, {FitParameterContainerItem::M_TYPE});
    registerTag(T_MINIMIZER, 1, 1, {MinimizerContainerItem::M_TYPE});
}

FitParameterContainerItem* FitSuiteItem::createFitParametersContainer()
{
    if (getItem(T_FIT_PARAMETERS_CONTAINER))
        throw Error("FitSuiteItem::createFitParametersContainer() -> Error. Attempt to create "
                    "a second FitParameterContainer.");

    return model()->insertItem<FitParameterContainerItem>(this, -1, T_FIT_PARAMETERS_CONTAINER);
}

FitParameterContainerItem* FitSuiteItem::fitParameterContainerItem()
{
    return item<FitParameterContainerItem>(T_FIT_PARAMETERS_CONTAINER);
}

MinimizerContainerItem* FitSuiteItem::createMinimizerContainer()
{
    if (getItem(T_MINIMIZER))
        throw Error("FitSuiteItem::createMinimizerContainer() -> Error. Attempt to create "
                    "a second MinimizerContainer.");

    return model()->insertItem<MinimizerContainerItem>(this, -1, T_MINIMIZER);
}

MinimizerContainerItem* FitSuiteItem::minimizerContainerItem()
{
    return item<MinimizerContainerItem>(T_MINIMIZER);
}

int FitSuiteItem::updateInterval() const
{
    return getItemValue(P_UPDATE_INTERVAL).toInt();
}

void FitSuiteItem::setUpdateInterval(const int interval)
{
    setItemValue(P_UPDATE_INTERVAL, interval);
    emit updateIntervalChanged(interval);
}

bool FitSuiteItem::isUpdateIntervalPropertyName(const QString& name)
{
    return name == P_UPDATE_INTERVAL;
}

int FitSuiteItem::iterationCount() const
{
    return getItemValue(P_ITERATION_COUNT).toInt();
}

void FitSuiteItem::setIterationCount(const int count)
{
    setItemValue(P_ITERATION_COUNT, count);
    emit iterationCountChanged(count);
}

bool FitSuiteItem::isIterationCountPropertyName(const QString& name)
{
    return name == P_ITERATION_COUNT;
}

double FitSuiteItem::chi2() const
{
    return getItemValue(P_CHI2).toDouble();
}

void FitSuiteItem::setChi2(const double chi2)
{
    setItemValue(P_CHI2, chi2);
}
