//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/MakeItem/ItemCatalog.cpp
//! @brief     Implements class ItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/MakeItem/ItemCatalog.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/BaseItem/PropertyItem.h"
#include "GUI/Model/Data/IntensityDataItem.h"
#include "GUI/Model/Data/ProjectionItems.h"
#include "GUI/Model/Data/RealItem.h"
#include "GUI/Model/Data/SpecularDataItem.h"
#include "GUI/Model/Device/MaskItems.h"
#include "GUI/Model/Device/PointwiseAxisItem.h"
#include "GUI/Model/Job/FitParameterContainerItem.h"
#include "GUI/Model/Job/FitParameterItem.h"
#include "GUI/Model/Job/FitParameterLinkItem.h"
#include "GUI/Model/Job/FitSuiteItem.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/Model/Job/MinimizerItem.h"

ItemCatalog::ItemCatalog()
{
    addItem<PropertyItem>();

    addItem<JobItem>();

    addItem<IntensityDataItem>();
    addItem<SpecularDataItem>();

    addItem<BasicAxisItem>();
    addItem<PointwiseAxisItem>();
    addItem<AmplitudeAxisItem>();

    addItem<MaskContainerItem>();
    addItem<RectangleItem>();
    addItem<PolygonPointItem>();
    addItem<PolygonItem>();
    addItem<VerticalLineItem>();
    addItem<HorizontalLineItem>();
    addItem<EllipseItem>();
    addItem<MaskAllItem>();

    addItem<RegionOfInterestItem>();

    addItem<FitParameterContainerItem>();
    addItem<FitParameterItem>();
    addItem<FitParameterLinkItem>();
    addItem<FitSuiteItem>();

    addItem<RealItem>();

    addItem<MinimizerContainerItem>();
    addItem<MinuitMinimizerItem>();
    addItem<GSLMultiMinimizerItem>();
    addItem<GeneticMinimizerItem>();
    addItem<SimAnMinimizerItem>();
    addItem<GSLLMAMinimizerItem>();

    addItem<ProjectionContainerItem>();
}

ItemCatalog& ItemCatalog::instance()
{
    static ItemCatalog catalog;
    return catalog;
}

std::unique_ptr<SessionItem> ItemCatalog::createItemPtr(const QString& modelType) const
{
    ASSERT(m_data.contains(modelType));
    return m_data.createItemPtr(modelType);
}

template <typename T>
void ItemCatalog::addItem()
{
    m_data.registerItem(T::M_TYPE, [] { return new T(); });
}
