//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Model/ApplicationModels.h
//! @brief     Defines class holding all application models
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MODEL_APPLICATIONMODELS_H
#define BORNAGAIN_GUI_MODEL_MODEL_APPLICATIONMODELS_H

#include <QObject>

class SessionModel;
class SessionItem;
class DocumentModel;
class InstrumentCollection;
class RealModel;
class JobModel;
class MessageService;

class ApplicationModels : public QObject {
    Q_OBJECT
public:
    ApplicationModels();

    RealModel* realModel() const;
    JobModel* jobModel() const;

    void writeTo(class QXmlStreamWriter* writer);
    void readFrom(class QXmlStreamReader* reader, MessageService* messageService);

    //! Returns all non-XML items
    QVector<SessionItem*> nonXMLItems() const;

signals:
    void modelChanged();

private:
    void connectModel(SessionModel* model) const;

    RealModel* m_realDataModel;
    JobModel* m_jobModel;
};

#endif // BORNAGAIN_GUI_MODEL_MODEL_APPLICATIONMODELS_H
