//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MesoCrystalItem.h
//! @brief     Defines class MesoCrystalItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_MESOCRYSTALITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_MESOCRYSTALITEM_H

#include "GUI/Model/Descriptor/SelectionProperty.h"
#include "GUI/Model/Descriptor/VectorProperty.h"
#include "GUI/Model/Sample/FormFactorItems.h"
#include "GUI/Model/Sample/ItemWithParticles.h"
#include "Sample/Lattice/Lattice3D.h"
#include <memory>

class IFormFactor;
class IParticle;
class MesoCrystal;
class MaterialItems;

class MesoCrystalItem : public ItemWithParticles {
public:
    explicit MesoCrystalItem(const MaterialItems* materials);
    void serialize(Streamer& s) override;

    std::unique_ptr<MesoCrystal> createMesoCrystal() const;

    Lattice3D getLattice() const;
    std::unique_ptr<IParticle> getBasis() const;

    std::unique_ptr<IFormFactor> getOuterShape() const;
    template <typename T>
    T* setOuterShapeType();

    SelectionDescriptor<FormFactorItem*> outerShape() const;
    void setOuterShape(FormFactorItem* p);

    ItemWithParticles* basisParticle() const;
    void setBasis(ItemWithParticles* basis);

    void setRawDataVectorA(const R3& vector_a);
    void setRawDataVectorB(const R3& vector_b);
    void setRawDataVectorC(const R3& vector_c);

    VectorDescriptor vectorA() const;
    VectorDescriptor vectorB() const;
    VectorDescriptor vectorC() const;

    QVector<ItemWithParticles*> containedItemsWithParticles() const override;

private:
    VectorProperty m_vectorA;
    VectorProperty m_vectorB;
    VectorProperty m_vectorC;
    SelectionProperty<FormFactorItem*> m_outerShape;
    SelectionProperty<ItemWithParticles*> m_basisParticle;
    const MaterialItems* m_materials;
};

template <typename T>
T* MesoCrystalItem::setOuterShapeType()
{
    auto* p = new T();
    setOuterShape(p);
    return p;
}

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_MESOCRYSTALITEM_H
