//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MultiLayerItem.h
//! @brief     Defines class MultiLayerItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H

#include "GUI/Model/Descriptor/DoubleProperty.h"
#include "GUI/Model/Descriptor/VectorProperty.h"
#include "GUI/Model/Sample/MaterialItems.h"
#include <QString>
#include <QUuid>
#include <QVector>

class LayerItem;
class ItemWithMaterial;
class QXmlStreamReader;
class QXmlStreamWriter;
class Streamer;

class MultiLayerItem {
public:
    MultiLayerItem();

    void initFrom(const MultiLayerItem* other);

    QVector<ItemWithMaterial*> itemsWithMaterial() const;

    void addStandardMaterials();

    QString sampleName() const;
    void setSampleName(const QString& name);

    QString description() const;
    void setDescription(const QString& description);

    DoubleDescriptor crossCorrLength() const;

    R3 externalField() const;
    void setExternalField(const R3& externalField);
    VectorDescriptor externalFieldVector() const;

    QVector<LayerItem*> layers() const;

    //! Creates and inserts a layer at given index.
    //!
    //! No properties etc. have been initialized, this  has to be done by the caller
    //! If index = -1, create a layer at the end of the list.
    LayerItem* addLayer(int index = -1);

    void removeLayer(LayerItem* item);
    void moveLayer(LayerItem* item, LayerItem* beforeThisLayer);

    void writeContentTo(QXmlStreamWriter* writer) const;
    void readContentFrom(QXmlStreamReader* reader);
    void serialize(Streamer& s);

    MaterialItems& materialItems();
    const MaterialItems& materialItems() const;

private:
    QString m_name;
    QString m_description;
    DoubleProperty m_crossCorrelationLength;
    VectorProperty m_externalField;
    QVector<LayerItem*> m_layers;
    MaterialItems m_materials;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H
