//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MultiLayerItems.cpp
//! @brief     Implements class MultiLayerItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/MultiLayerItems.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/MultiLayerItem.h"
#include "GUI/Support/XML/Serialize.h"
#include <QApplication>

MultiLayerItems::~MultiLayerItems()
{
    qDeleteAll(m_samples);
}

QVector<MultiLayerItem*> MultiLayerItems::sampleItems() const
{
    return m_samples;
}

MultiLayerItem* MultiLayerItems::addMultiLayer()
{
    m_samples << new MultiLayerItem();
    return m_samples.back();
}

void MultiLayerItems::addMultiLayer(MultiLayerItem* sample)
{
    m_samples << sample;
}

void MultiLayerItems::removeMultiLayer(MultiLayerItem* sample)
{
    m_samples.removeAll(sample);
    delete sample;
}

QStringList MultiLayerItems::sampleNames() const
{
    QStringList existingNames;
    for (const auto* item : m_samples)
        existingNames << item->sampleName();
    return existingNames;
}

void MultiLayerItems::serialize(Streamer& s)
{
    s.assertVersion(0);
    Serialize::rwVector(s, "Multilayers", m_samples);
}
