//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Coherence/CoherentFFSum.h
//! @brief     Defines class CoherentFFSum.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_COHERENCE_COHERENTFFSUM_H
#define BORNAGAIN_RESAMPLE_COHERENCE_COHERENTFFSUM_H

#include "Base/Spin/SpinMatrix.h"
#include <heinz/Complex.h>
#include <memory>
#include <vector>

class SumDWBA;
class DiffuseElement;

//! Information about particle form factor and abundance.

class CoherentFFSum {
public:
    CoherentFFSum(double abundance, std::vector<std::shared_ptr<const SumDWBA>> terms);

    complex_t summedFF(const DiffuseElement& ele) const;
    SpinMatrix summedPolFF(const DiffuseElement& ele) const;

    double relativeAbundance() const { return m_abundance; }
    double radialExtension() const;

private:
    const double m_abundance;
    const std::vector<std::shared_ptr<const SumDWBA>> m_terms;
};

#endif // BORNAGAIN_RESAMPLE_COHERENCE_COHERENTFFSUM_H
#endif // USER_API
