//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/PlatonicTetrahedron.cpp
//! @brief     Implements class PlatonicTetrahedron.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/HardParticle/PlatonicTetrahedron.h"
#include "Base/Math/Constants.h"
#include "Base/Math/Functions.h"
#include <ff/Platonic.h>

PlatonicTetrahedron::PlatonicTetrahedron(const std::vector<double> P)
    : IFormFactorPolyhedron(P)
    , m_edge(m_P[0])
{
    checkNodeArgs();
    setPolyhedron(ff::platonic::Tetrahedron::topology(), -height() / 4,
                  ff::platonic::Tetrahedron::vertices(m_edge));
    assert_platonic();
}

PlatonicTetrahedron::PlatonicTetrahedron(double edge)
    : PlatonicTetrahedron(std::vector<double>{edge})
{
}
