//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/TruncatedSphere.h
//! @brief     Defines class TruncatedSphere.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_TRUNCATEDSPHERE_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_TRUNCATEDSPHERE_H

#include "Sample/Particle/IFormFactor.h"

//! A truncated Sphere.
//! @ingroup hardParticle

class TruncatedSphere : public IFormFactor {
public:
    TruncatedSphere(double radius, double height, double dh);
#ifndef USER_API
    TruncatedSphere(std::vector<double> P);

    TruncatedSphere* clone() const override
    {
        return new TruncatedSphere(m_radius, m_height, m_dh);
    }
    std::string className() const final { return "TruncatedSphere"; }
    // const auto tooltip = "class_tooltip";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Radius", "nm", "radius", 0, +INF, 0},
                {"Height", "nm", "height before removal of cap", 0, +INF, 0},
                {"DeltaHeight", "nm", "height of removed cap", 0, +INF, 0}};
    }

    double height() const { return m_height; }
    double radius() const { return m_radius; }
    double removedTop() const { return m_dh; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius;
    const double& m_height;
    const double& m_dh;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_TRUNCATEDSPHERE_H
