//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Particle/ParticleComposition.h
//! @brief     Defines class ParticleComposition.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_PARTICLE_PARTICLECOMPOSITION_H
#define BORNAGAIN_SAMPLE_PARTICLE_PARTICLECOMPOSITION_H

#include "Base/Types/OwningVector.h"
#include "Sample/Particle/IParticle.h"

//! A composition of particles at fixed positions
//! @ingroup samples

class ParticleComposition : public IParticle {
public:
    ParticleComposition();

    ~ParticleComposition() override;

    ParticleComposition* clone() const override;
    std::string className() const final { return "ParticleComposition"; }
    std::vector<const INode*> nodeChildren() const override;

#ifndef SWIG
    std::vector<std::unique_ptr<IParticle>> decompose() const override;
#endif

    void addParticle(const IParticle& particle);
    void addParticle(const IParticle& particle, R3 position);
    void addParticles(const IParticle& particle, std::vector<R3> positions);

    //! Returns number of different particles
    size_t nbrParticles() const { return m_particles.size(); }

    std::vector<const IParticle*> particles() const;

private:
    OwningVector<IParticle> m_particles;
};

#endif // BORNAGAIN_SAMPLE_PARTICLE_PARTICLECOMPOSITION_H
