//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Particle/ParticleCoreShell.h
//! @brief     Defines ParticleCoreShell.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_PARTICLE_PARTICLECORESHELL_H
#define BORNAGAIN_SAMPLE_PARTICLE_PARTICLECORESHELL_H

#include "Sample/Particle/IParticle.h"

class Particle;

//! A particle with a core/shell geometry.
//! @ingroup samples

class ParticleCoreShell : public IParticle {
public:
    ParticleCoreShell(const Particle& shell, const Particle& core,
                      R3 relative_core_position = R3(0.0, 0.0, 0.0));
    ~ParticleCoreShell() override;

    ParticleCoreShell* clone() const override;
    std::string className() const final { return "ParticleCoreShell"; }
    std::vector<const INode*> nodeChildren() const override;

    const Particle* shellParticle() const { return m_shell.get(); }
    const Particle* coreParticle() const { return m_core.get(); }

protected:
    std::unique_ptr<Particle> m_shell;
    std::unique_ptr<Particle> m_core;
};

#endif // BORNAGAIN_SAMPLE_PARTICLE_PARTICLECORESHELL_H
