//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Simulation/ScatteringSimulation.h
//! @brief     Defines class ScatteringSimulation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SIM_SIMULATION_SCATTERINGSIMULATION_H
#define BORNAGAIN_SIM_SIMULATION_SCATTERINGSIMULATION_H

#include "Sim/Simulation/ISimulation2D.h"

class MultiLayer;

//! GISAS simulation.
//!
//! Holds an instrument and sample model.
//! Computes the scattered intensity as function of 2D detector coordinates.
//! @ingroup simulation

class ScatteringSimulation : public ISimulation2D {
public:
    ScatteringSimulation(const Beam& beam, const MultiLayer& sample, const IDetector& detector);
    ~ScatteringSimulation() override = default;

    std::string className() const final { return "ScatteringSimulation"; }

#ifndef SWIG
    ICoordSystem* createCoordSystem() const override;

private:
    SimulationResult pack_result() override;

    //! Put into a clean state for running a simulation
    void prepareSimulation() override;

    //! Initializes the vector of ISimulation elements
    void initElementVector() override;
#endif // SWIG
};

#endif // BORNAGAIN_SIM_SIMULATION_SCATTERINGSIMULATION_H
