+++
title = "Modify the script"
weight = 40
+++

## Expanded simulation script

As a first step towards writing sample and simulation specifications
of your own, let us expand the simulation script
[AlternatingLayers.py]({{% ref-src "Examples/specular/AlternatingLayers.py" %}})
from the preceding pages.
Instead of the shorthand calls to modules
[std_samples]({{% ref-src "Wrap/Python/std_samples.py" %}}) and
[std_simulations]({{% ref-src "Wrap/Python/std_simulations.py" %}}),
we provide explicit code for the functions `get_sample` and `get_simulation`:
{{< highlightfile file="Examples/specular/AlternatingLayers1.py">}}
<p>

### Sample

`get_sample` is a function without arguments.
It returns an object of type [MultiLayer]({{% ref-api "classMultiLayer" %}}).

The return statement is preceded by three stances.
Each stance starts with a comment line,
{{< highlight python >}}
    # comment extends from hash character to end of line
{{< /highlight >}}

BornAgain functions that start with a capital letter,
like `MaterialBySLD` or `Layer` are _constructors_ or
constructor-like global functions.
They return new _objects_. An object is an instance of a _class_.
The function `MaterialBySLD` instantiates an object of type
[Material]({{% ref-api "classMaterial" %}})
the function `Layer` an object of type
[Layer]({{% ref-api "classLayer" %}}).

Function like `addLayer` is a member function of class
[MultiLayer]({{% ref-api "classMultiLayer" %}}).
This can be seen from the two lines
{{< highlight python >}}
    sample = ba.MultiLayer()
    sample.addLayer(ambient_layer)
{{< /highlight >}}
where `sample` is created as a new instance of class `MultiLayer`.

### Simulation

`get_simulation(sample, scan_size=500)` is a function with one
required argument (`sample`) and one optional keyword argument
(`scan_size`). If the function is called with only one argument,
then `scan_size` is assigned the default value 500.

`angstrom` and `deg` are numeric constants. They are used to
convert physical quantities to internal units nanometer and radian.

The function returns an object of type
[SpecularSimulation]({{% ref-api "classSpecularSimulation" %}}).
